-- Create the bread table
CREATE TABLE IF NOT EXISTS bread (
    item_id INTEGER PRIMARY KEY,
    name TEXT NOT NULL,
    price REAL NOT NULL
);

-- Clear any existing data to ensure idempotency
DELETE FROM bread;

-- Insert data into the bread table
INSERT INTO bread (item_id, name, price) VALUES
(1, 'Brioche', 3.00),
(2, 'Baguette', 3.00),
(3, 'Garlic Baguette', 3.00);

-- Create the cakes table
CREATE TABLE IF NOT EXISTS cakes (
    cake_id INTEGER PRIMARY KEY,
    cake_name TEXT NOT NULL,
    price REAL NOT NULL,
    available TEXT CHECK(available IN ('Yes', 'No')) NOT NULL
);

-- Clear any existing data to ensure idempotency
DELETE FROM cakes;

-- Insert data into the cakes table
INSERT INTO cakes (cake_id, cake_name, price, available) VALUES
(1, 'Rainbow Celebration Cake', 25.00, 'No'),
(2, 'Black Forest Gateau', 18.00, 'No'),
(3, 'Cheesecake', 15.00, 'Yes'),
(4, 'Carrot Cake', 16.00, 'Yes'),
(5, 'Red Velvet Cake', 20.00, 'Yes');

-- Create the customer_favorites table
CREATE TABLE IF NOT EXISTS customer_favorites (
    customer_id INTEGER PRIMARY KEY,
    favorite_item TEXT NOT NULL
);

-- Clear any existing data to ensure idempotency
DELETE FROM customer_favorites;

-- Insert data into the customer_favorites table
INSERT INTO customer_favorites (customer_id, favorite_item) VALUES
(1, 'Chocolate Cake'),
(2, 'Lemon Tart'),
(3, 'Vanilla Cupcake'),
(4, 'Blueberry Muffin'),
(5, 'Chocolate Chip Cookie');

-- Create the ingredients table
CREATE TABLE IF NOT EXISTS ingredients (
    ingredient_id INTEGER PRIMARY KEY,
    ingredient_name TEXT NOT NULL,
    quantity_in_stock INTEGER NOT NULL,
    price REAL NOT NULL,
    supplier TEXT NOT NULL
);

-- Clear any existing data to ensure idempotency
DELETE FROM ingredients;

-- Insert data into the ingredients table
INSERT INTO ingredients (ingredient_id, ingredient_name, quantity_in_stock, price, supplier) VALUES
(1, 'All-Purpose Flour', 200, 1.50, 'Bakery Supplies Co.'),
(2, 'Sugar', 150, 1.20, 'Bakery Supplies Co.'),
(3, 'Cocoa Powder', 30, 3.00, 'ChocoDelight'),
(4, 'Sprinkles', 10, 4.00, 'CakeDecor'),
(5, 'Butter', 50, 2.50, 'DairyBest');

-- Create the orders table
CREATE TABLE IF NOT EXISTS orders (
    order_id INTEGER PRIMARY KEY,
    customer_id INTEGER NOT NULL,
    order_status TEXT NOT NULL,
    total_amount REAL NOT NULL,
    FOREIGN KEY (customer_id) REFERENCES customer_favorites (customer_id)
);

-- Clear any existing data to ensure idempotency
DELETE FROM orders;

-- Insert data into the orders table
INSERT INTO orders (order_id, customer_id, order_status, total_amount) VALUES
(101, 1, 'Completed', 15.00),
(102, 2, 'Processing', 22.50),
(103, 3, 'Ready for Pickup', 18.00),
(104, 4, 'Completed', 30.00),
(105, 5, 'Processing', 20.00);
