-- Create the order_items table
CREATE TABLE IF NOT EXISTS order_items (
    order_item_id INTEGER PRIMARY KEY,
    order_id INTEGER NOT NULL,
    product_id INTEGER NOT NULL,
    quantity INTEGER NOT NULL
);

-- Clear any existing data to ensure idempotency
DELETE FROM order_items;

-- Insert data into the order_items table
INSERT INTO order_items (order_item_id, order_id, product_id, quantity) VALUES
(301, 201, 1, 1),
(302, 201, 2, 1),
(303, 202, 3, 1),
(304, 203, 4, 1),
(305, 204, 5, 2),
(306, 205, 6, 1),
(307, 206, 7, 1),
(308, 207, 8, 3),
(309, 208, 9, 2),
(310, 209, 10, 1),
(311, 210, 1, 1),
(312, 210, 2, 1);

-- Create the orders table
CREATE TABLE IF NOT EXISTS orders (
    order_id INTEGER PRIMARY KEY,
    subscriber_id INTEGER NOT NULL,
    order_date DATE NOT NULL,
    order_status TEXT NOT NULL,
    total_amount REAL NOT NULL
);

-- Clear any existing data to ensure idempotency
DELETE FROM orders;

-- Insert data into the orders table
INSERT INTO orders (order_id, subscriber_id, order_date, order_status, total_amount) VALUES
(201, 101, '2024-06-01', 'Processing', 49.99),
(202, 102, '2024-06-02', 'Processing', 29.99),
(203, 103, '2024-06-03', 'Processing', 67.50),
(204, 104, '2024-06-04', 'Delivered', 52.50),
(205, 105, '2024-06-05', 'Processing', 39.99),
(206, 106, '2024-06-06', 'Processing', 19.99),
(207, 107, '2024-06-07', 'Shipped', 59.99),
(208, 108, '2024-06-08', 'Delivered', 29.99),
(209, 109, '2024-06-09', 'Processing', 69.99),
(210, 110, '2024-06-10', 'Processing', 49.99);

-- Create the products table
CREATE TABLE IF NOT EXISTS products (
    product_id INTEGER PRIMARY KEY,
    product_name TEXT NOT NULL,
    category TEXT NOT NULL,
    price REAL NOT NULL,
    brand TEXT NOT NULL,
    in_stock INTEGER NOT NULL CHECK (in_stock >= 0)
);

-- Clear any existing data to ensure idempotency
DELETE FROM products;

-- Insert data into the products table
INSERT INTO products (product_id, product_name, category, price, brand, in_stock) VALUES
(1, 'Glow Serum', 'Placeholder', 39.99, 'Luminance', 1),
(2, 'Volume Mascara', 'Makeup', 28.99, 'North Bergamot', 1),
(3, 'Luxury Face Cream', 'Skincare', 89.99, 'Royal Toronto Skincare', 1),
(4, 'Hair Mask', 'Haircare', 29.99, 'Royal Toronto Skincare', 10),
(5, 'Hydrating Lip Balm', 'Skincare', 12.99, 'North Bergamot', 1),
(6, 'Exfoliating Scrub', 'Skincare', 19.99, 'Luminance', 1),
(7, 'Moisturizing Lotion', 'Skincare', 15.99, 'North Bergamot', 1),
(8, 'Shampoo', 'Haircare', 9.99, 'Elements by the Bay', 1),
(9, 'Conditioner', 'Haircare', 9.99, 'Elements by the Bay', 1),
(10, 'Eye Shadow Palette', 'Makeup', 19.99, 'North Bergamot', 1);

-- Create the subscribers table
CREATE TABLE IF NOT EXISTS subscribers (
    subscriber_id INTEGER PRIMARY KEY,
    first_name TEXT NOT NULL,
    last_name TEXT NOT NULL,
    email TEXT NOT NULL UNIQUE,
    subscription_type TEXT NOT NULL,
    shipping_address TEXT NOT NULL
);

-- Clear any existing data to ensure idempotency
DELETE FROM subscribers;

-- Insert data into the subscribers table
INSERT INTO subscribers (subscriber_id, first_name, last_name, email, subscription_type, shipping_address) VALUES
(101, 'Sophia', 'Brown', 'sophia.brown@upskew.com', 'Monthly', '123 Maple Street'),
(102, 'Liam', 'James', 'james@upskew.com', 'Monthly', '456 Oak Avenue'),
(103, 'Ava', 'Davis', 'ava.davis@upskew.com', 'Monthly', '789 Pine Road'),
(104, 'Fred', 'Johnson', 'fred.johnson@upskew.com', 'Monthly', '1 Elm Street'),
(105, 'Emma', 'Wilson', 'emmam@upskew.com', 'Annual', '321 Birch Lane'),
(106, 'Oliver', 'Rodriguez', 'oliver129@upskew.com', 'Monthly', '654 Cedar Street'),
(107, 'Isabella', 'Taylor', 'isabella888@upskew.com', 'Annual', '987 Willow Drive'),
(108, 'Lucas', 'Anderson', 'landerson@upskew.com', 'Monthly', '111 Fir Street'),
(109, 'Mia', 'Thomas', 'miat@upskew.com', 'Annual', '222 Spruce Avenue'),
(110, 'Noah', 'White', 'noaw@upskew.com', 'Monthly', '333 Redwood Road');
