-- Create the zones table
CREATE TABLE IF NOT EXISTS zones (
    zone_id INTEGER PRIMARY KEY,
    zone_type TEXT NOT NULL
);

-- Clear any existing data in zones to ensure idempotency
DELETE FROM zones;

-- Insert data into the zones table
INSERT INTO zones (zone_id, zone_type) VALUES
(1, 'Residential'),
(2, 'Commercial'),
(3, 'Industrial'),
(4, 'Agricultural'),
(5, 'Park'),
(6, 'Educational'),
(7, 'Healthcare'),
(8, 'Entertainment'),
(9, 'Public Service'),
(10, 'Transport');

-- Create the buildings table
CREATE TABLE IF NOT EXISTS buildings (
    building_id INTEGER PRIMARY KEY,
    building_type TEXT NOT NULL,
    capacity INTEGER NOT NULL,
    zone_id INTEGER NOT NULL,
    FOREIGN KEY (zone_id) REFERENCES zones(zone_id)
);

-- Clear any existing data in buildings to ensure idempotency
DELETE FROM buildings;

-- Insert data into the buildings table
INSERT INTO buildings (building_id, building_type, capacity, zone_id) VALUES
(1, 'Residential', 120, 1),
(2, 'Commercial', 50, 2),
(3, 'Residential', 200, 1),
(4, 'Industrial', 30, 3),
(5, 'Residential', 80, 1),
(6, 'Residential', 150, 1),
(7, 'Commercial', 80, 2),
(8, 'Residential', 100, 1),
(9, 'Industrial', 40, 3),
(10, 'Residential', 90, 1),
(11, 'Commercial', 60, 2),
(12, 'Park', 200, 4),
(13, 'School', 100, 1),
(14, 'Hospital', 50, 1),
(15, 'Shopping Mall', 150, 2);

-- Create the jobs table
CREATE TABLE IF NOT EXISTS jobs (
    job_id INTEGER PRIMARY KEY,
    job_title TEXT NOT NULL,
    salary INTEGER NOT NULL,
    workplace_id INTEGER NOT NULL,
    FOREIGN KEY (workplace_id) REFERENCES buildings(building_id)
);

-- Clear any existing data in jobs to ensure idempotency
DELETE FROM jobs;

-- Insert data into the jobs table
INSERT INTO jobs (job_id, job_title, salary, workplace_id) VALUES
(1, 'Software Engineer', 90000, 2),
(2, 'Teacher', 65000, 6),
(3, 'Factory Worker', 50000, 4),
(4, 'Farmer', 45000, 7),
(5, 'Barista', 35000, 2),
(6, 'Doctor', 120000, 14),
(7, 'Bus Driver', 55000, 10),
(8, 'Police Officer', 70000, 9),
(9, 'Musician', 60000, 8),
(10, 'Park Ranger', 48000, 5),
(11, 'Chef', 58000, 15),
(12, 'Librarian', 52000, 6),
(13, 'Mechanic', 62000, 3),
(14, 'Electrician', 68000, 3),
(15, 'Accountant', 75000, 2);

-- Create the citizens table
CREATE TABLE IF NOT EXISTS citizens (
    citizen_id INTEGER PRIMARY KEY,
    first_name TEXT NOT NULL,
    last_name TEXT NOT NULL,
    happiness INTEGER NOT NULL,
    building_id INTEGER NOT NULL,
    FOREIGN KEY (building_id) REFERENCES buildings(building_id)
);

-- Clear any existing data in citizens to ensure idempotency
DELETE FROM citizens;

-- Insert data into the citizens table
INSERT INTO citizens (citizen_id, first_name, last_name, happiness, building_id) VALUES
(1, 'Olivia', 'Nguyen', 85, 1),
(2, 'Ethan', 'Smith', 72, 3),
(3, 'Sophia', 'Chen', 92, 2),
(4, 'Noah', 'Williams', 65, 4),
(5, 'Ava', 'Brown', 78, 5),
(6, 'Liam', 'Garcia', 95, 6),
(7, 'Isabella', 'Rodriguez', 70, 8),
(8, 'James', 'Wilson', 68, 9),
(9, 'Mia', 'Anderson', 82, 10),
(10, 'Benjamin', 'Taylor', 76, 1),
(11, 'Charlotte', 'Moore', 88, 3),
(12, 'Elijah', 'Jackson', 63, 2),
(13, 'Amelia', 'Martin', 91, 4),
(14, 'Logan', 'Lee', 79, 5),
(15, 'Harper', 'Lewis', 73, 7);

-- Create the citizen_jobs table
CREATE TABLE IF NOT EXISTS citizen_jobs (
    citizen_id INTEGER NOT NULL,
    job_id INTEGER NOT NULL,
    PRIMARY KEY (citizen_id, job_id),
    FOREIGN KEY (citizen_id) REFERENCES citizens(citizen_id),
    FOREIGN KEY (job_id) REFERENCES jobs(job_id)
);

-- Clear any existing data in citizen_jobs to ensure idempotency
DELETE FROM citizen_jobs;

-- Insert data into the citizen_jobs table
INSERT INTO citizen_jobs (citizen_id, job_id) VALUES
(1, 1),
(2, 3),
(3, 2),
(4, 5),
(5, 6),
(6, 2),
(7, 9),
(8, 13),
(9, 11),
(10, 5),
(11, 15),
(12, 4),
(13, 8),
(14, 10),
(15, 12);
