-- Create the categories table if it doesn't already exist
CREATE TABLE IF NOT EXISTS categories (
    category_id INTEGER PRIMARY KEY,
    category TEXT,
    description TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM categories;

-- Insert data into the categories table
INSERT INTO categories (category_id, category, description) VALUES
(1, 'Time', 'Sounds related to time and clocks'),
(2, 'Footsteps', 'Various footstep sounds for suspense'),
(3, 'Ambient', 'Background noises and atmospheres'),
(4, 'Weather', 'Sounds of weather and nature'),
(5, 'Animals', 'Animal vocalizations'),
(6, 'Vehicles', 'Transportation related sounds'),
(7, 'Objects', 'Everyday object sounds'),
(8, 'Sirens', 'Emergency or alert siren sounds for suspense');

-- Create the characters table if it doesn't already exist
CREATE TABLE IF NOT EXISTS characters (
    character_id INTEGER PRIMARY KEY,
    character_name TEXT,
    occupation TEXT,
    role TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM characters;

-- Insert data into the characters table
INSERT INTO characters (character_id, character_name, occupation, role) VALUES
(1, 'Professor Chronos', 'Inventor', 'Protagonist'),
(2, 'Detective Parker', 'Police Detective', 'Deuteragonist'),
(3, 'Seth', 'Librarian', 'Supporting Character'),
(4, 'Mayor Bloom', 'Politician', 'Antagonist');

-- Create the episodes table if it doesn't already exist
CREATE TABLE IF NOT EXISTS episodes (
    episode_id INTEGER PRIMARY KEY,
    episode_title TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM episodes;

-- Insert data into the episodes table
INSERT INTO episodes (episode_id, episode_title) VALUES
(1, 'The Case of the Missing Time Traveler'),
(2, 'The Mystery of the Talking Cat'),
(3, 'The Secret of the Old Clock Tower'),
(4, 'The Riddle of the Whistling Kettle');

-- Create the scenes table if it doesn't already exist
CREATE TABLE IF NOT EXISTS scenes (
    scene_id INTEGER PRIMARY KEY,
    episode_id INTEGER,
    sound_id INTEGER,
    character_id INTEGER,
    scene_description TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM scenes;

-- Insert data into the scenes table
INSERT INTO scenes (scene_id, episode_id, sound_id, character_id, scene_description) VALUES
(1, 1, 1, 1, 'Professor Chronos examining his time machine'),
(2, 1, NULL, 2, 'Detective Parker following footprints'),
(3, 2, 6, 3, 'Seth''s cat talking in her apartment'),
(4, 2, 3, 1, 'Professor Chronos entering a hidden room'),
(5, 3, 8, 2, 'Detective Parker receiving a mysterious call'),
(6, 3, 4, 3, 'Seth hearing whispers in the clock tower'),
(7, 1, 5, 1, 'Professor Chronos in a flashback scene with a breeze'),
(8, 2, 9, 2, 'Detective Parker caught in a sudden thunderstorm'),
(9, 4, NULL, 3, 'Seth in a peaceful garden setting'),
(10, 4, 10, 1, 'Professor Chronos startled by a dog barking');

-- Create the sound_cues table if it doesn't already exist
CREATE TABLE IF NOT EXISTS sound_cues (
    sound_cue_id INTEGER PRIMARY KEY,
    episode_id INTEGER,
    sound_id INTEGER,
    cue_description TEXT,
    timestamp TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM sound_cues;

-- Insert data into the sound_cues table
INSERT INTO sound_cues (sound_cue_id, episode_id, sound_id, cue_description, timestamp) VALUES
(1, 1, 1, 'Clock ticking intensifies as Professor examines machine', '00:10:15'),
(2, 1, 2, 'Footstep sounds as Detective follows clues', '00:22:30'),
(3, 2, 6, 'Cat meows a response to Seth''s question', '00:08:45'),
(4, 3, 4, 'Whispering voices grow louder as Seth climbs tower', '00:35:10'),
(5, 2, 9, 'Thunderclap coincides with a dramatic reveal', '00:19:55'),
(6, 4, 12, 'Bird chirping sets a tranquil scene in the garden', '00:04:20'),
(7, 1, 5, 'Gentle breeze during a peaceful flashback scene', '00:02:45'),
(8, 3, 8, 'Phone ringing interrupts a tense moment', '00:28:15');

-- Create the sounds table if it doesn't already exist
CREATE TABLE IF NOT EXISTS sounds (
    sound_id INTEGER PRIMARY KEY,
    sound_effect TEXT,
    file_format TEXT,
    category_id INTEGER,
    duration_seconds INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM sounds;

-- Insert data into the sounds table
INSERT INTO sounds (sound_id, sound_effect, file_format, category_id, duration_seconds) VALUES
(1, 'Clock Ticking', 'MP3', NULL, 25),
(2, 'Footsteps on Gravel', 'WAV', 2, 10),
(3, 'Door Creaking Open', 'MP3', NULL, 5),
(4, 'Mysterious Whispers', 'MP3', 4, 15),
(5, 'Gentle Breeze', 'WAV', 5, 30),
(6, 'Cat Meow', 'MP3', 6, 2),
(7, 'Car Engine Starting', 'WAV', 7, 8),
(8, 'Phone Ringing', 'MP3', 8, 12),
(9, 'Thunderclap', 'WAV', 5, 3),
(10, 'Dog Barking', 'MP3', 6, 7),
(11, 'Footsteps on Wood', 'MP3', 2, 18),
(12, 'Bird Chirping', 'WAV', 6, 4),
(13, 'Ocean Waves Crashing', 'MP3', 5, 45),
(14, 'Doorbell Ringing', 'WAV', 8, 6),
(15, 'Wind Chimes', 'MP3', 4, 20),
(16, 'Clock Alarm', 'WAV', 1, 10),
(17, 'Car Horn Honking', 'MP3', 7, 4),
(18, 'Cat Hissing', 'WAV', 6, 3),
(19, 'Police Siren', 'MP3', 8, 5);