-- Create the airlines table if it doesn't already exist
CREATE TABLE IF NOT EXISTS airlines (
    iata_code TEXT PRIMARY KEY,
    airline_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM airlines;

-- Insert data into the airlines table
INSERT INTO airlines (iata_code, airline_name) VALUES
('JN', 'Join Express'),
('LT', 'Limitless Lines'),
('DT', 'Distinct Airways'),
('SL', 'Select Airlines'),
('HV', 'Having Flights');

-- Create the airports table if it doesn't already exist
CREATE TABLE IF NOT EXISTS airports (
    airport_code TEXT PRIMARY KEY,
    city TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM airports;

-- Insert data into the airports table
INSERT INTO airports (airport_code, city) VALUES
('JFK', 'New York'),
('ORD', 'Chicago'),
('ATL', 'Atlanta'),
('LAS', 'Las Vegas'),
('LHR', 'London'),
('LAX', 'Los Angeles'),
('SFO', 'San Francisco'),
('HNL', 'Honolulu'),
('DEN', 'Denver'),
('MCO', 'Orlando'),
('SEA', 'Seattle');

-- Create the destinations table if it doesn't already exist
CREATE TABLE IF NOT EXISTS destinations (
    destination_id INTEGER PRIMARY KEY,
    destination_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM destinations;

-- Insert data into the destinations table
INSERT INTO destinations (destination_id, destination_name) VALUES
(1, 'Hawaii'),
(2, 'Italy'),
(3, 'Japan');

-- Create the flights table if it doesn't already exist
CREATE TABLE IF NOT EXISTS flights (
    flight_id INTEGER PRIMARY KEY,
    airline_code TEXT,
    origin_city TEXT,
    destination_city TEXT,
    price REAL
);

-- Clear any existing data to ensure idempotency
DELETE FROM flights;

-- Insert data into the flights table
INSERT INTO flights (flight_id, airline_code, origin_city, destination_city, price) VALUES
(1, 'JN', 'New York', 'Los Angeles', 450),
(2, 'LT', 'Chicago', 'Denver', 380),
(3, 'DT', 'Atlanta', 'Orlando', 200),
(4, 'SL', 'Las Vegas', 'San Francisco', 180),
(5, 'HV', 'London', 'New York', 700),
(6, 'JN', 'Los Angeles', 'Honolulu', 600),
(7, 'LT', 'San Francisco', 'Honolulu', 550),
(8, 'DT', 'Seattle', 'Honolulu', 620);

-- Create the travelers table if it doesn't already exist
CREATE TABLE IF NOT EXISTS travelers (
    traveler_id INTEGER PRIMARY KEY,
    traveler_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM travelers;

-- Insert data into the travelers table
INSERT INTO travelers (traveler_id, traveler_name) VALUES
(1, 'Elliot'),
(2, 'Eli'),
(3, 'Dakota'),
(4, 'Harper'),
(5, 'Andy'),
(6, 'Davis'),
(7, 'Finley'),
(8, 'Rowan');

-- Create the traveler_preferences table if it doesn't already exist
CREATE TABLE IF NOT EXISTS traveler_preferences (
    preference_id INTEGER PRIMARY KEY,
    traveler_id INTEGER,
    destination_id INTEGER,
    preferred_travel_month TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM traveler_preferences;

-- Insert data into the traveler_preferences table
INSERT INTO traveler_preferences (preference_id, traveler_id, destination_id, preferred_travel_month) VALUES
(1, 1, 1, 'June'),
(2, 2, 2, 'December'),
(3, 3, 3, 'May'),
(4, 4, 1, 'August'),
(5, 5, 2, 'July'),
(6, 6, 3, 'September'),
(7, 7, 1, 'February'),
(8, 8, 2, 'April');
