-- Create the city table if it doesn't already exist
CREATE TABLE IF NOT EXISTS city (
    city_id INTEGER PRIMARY KEY,
    city_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM city;

-- Insert data into the city table
INSERT INTO city (city_id, city_name) VALUES
(1, 'Dallas'),
(2, 'Houston'),
(3, 'Austin'),
(4, 'San Antonio');

-- Create the customers table if it doesn't already exist
CREATE TABLE IF NOT EXISTS customers (
    customer_id INTEGER PRIMARY KEY,
    customer_name TEXT,
    phone_number TEXT,
    email TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM customers;

-- Insert data into the customers table
INSERT INTO customers (customer_id, customer_name, phone_number, email) VALUES
(1, 'John Tan', '+1-555-123-4567', 'tan.john@upskew.com'),
(2, 'Eliza Davis', '+1-555-987-6543', 'daviseliza2000@upskew.com'),
(3, 'William Lee', '+1-555-246-8013', 'willlee@upskew.com'),
(4, 'Maria Garcia', '+1-555-369-1470', 'eva1337@upskew.com'),
(5, 'Sung Kim', '+1-555-789-0123', 'sun.m.kim@upskew.com');

-- Create the deliveries table if it doesn't already exist
CREATE TABLE IF NOT EXISTS deliveries (
    delivery_id INTEGER PRIMARY KEY,
    order_id INTEGER,
    driver_id INTEGER,
    delivery_time TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM deliveries;

-- Insert data into the deliveries table
INSERT INTO deliveries (delivery_id, order_id, driver_id, delivery_time) VALUES
(1, 1, 2, '2023-10-26 18:30:00'),
(2, 2, 1, '2023-10-27 19:15:00'),
(3, 4, 3, '2023-10-28 20:00:00'),
(4, 5, NULL, '2023-10-28 21:45:00');

-- Create the drivers table if it doesn't already exist
CREATE TABLE IF NOT EXISTS drivers (
    driver_id INTEGER PRIMARY KEY,
    driver_name TEXT,
    vehicle_type TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM drivers;

-- Insert data into the drivers table
INSERT INTO drivers (driver_id, driver_name, vehicle_type) VALUES
(1, 'Alice Marie', 'Car'),
(2, 'Robb Williams', 'Bike'),
(3, 'Charlie Williams', 'Scooter'),
(4, 'Louise Brown', 'Car');

-- Create the menu_items table if it doesn't already exist
CREATE TABLE IF NOT EXISTS menu_items (
    item_id INTEGER PRIMARY KEY,
    restaurant_id INTEGER,
    item_name TEXT,
    price REAL
);

-- Clear any existing data to ensure idempotency
DELETE FROM menu_items;

-- Insert data into the menu_items table
INSERT INTO menu_items (item_id, restaurant_id, item_name, price) VALUES
(1, 1, 'Milk Tea', 5.00),
(2, 1, 'Taro Smoothie', 6.50),
(3, 2, 'Cheeseburger', 10.00),
(4, 2, 'Fries', 2.75),
(5, 3, 'Pasta Carbonara', 15.00),
(6, NULL, 'Mystery Meat Pizza', 12.00);

-- Create the orders table if it doesn't already exist
CREATE TABLE IF NOT EXISTS orders (
    order_id INTEGER PRIMARY KEY,
    customer_id INTEGER,
    restaurant_id INTEGER,
    order_date TEXT,
    total_amount REAL,
    promotion_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM orders;

-- Insert data into the orders table
INSERT INTO orders (order_id, customer_id, restaurant_id, order_date, total_amount, promotion_id) VALUES
(1, 1, 2, '2023-10-26', 25.50, 1),
(2, 3, 1, '2023-10-27', 18.75, NULL),
(3, NULL, 3, '2023-10-27', 32.00, NULL),
(4, 2, 2, '2023-10-28', 21.20, 1),
(5, 5, 4, '2023-10-28', 40.80, 3);

-- Create the promotions table if it doesn't already exist
CREATE TABLE IF NOT EXISTS promotions (
    promotion_id INTEGER PRIMARY KEY,
    promotion_name TEXT,
    discount_percentage INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM promotions;

-- Insert data into the promotions table
INSERT INTO promotions (promotion_id, promotion_name, discount_percentage) VALUES
(1, 'Grand Opening', 10),
(2, 'Weekday Special', 15),
(3, 'Free Delivery', 0);

-- Create the restaurants table if it doesn't already exist
CREATE TABLE IF NOT EXISTS restaurants (
    restaurant_id INTEGER PRIMARY KEY,
    restaurant_name TEXT,
    city_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM restaurants;

-- Insert data into the restaurants table
INSERT INTO restaurants (restaurant_id, restaurant_name, city_id) VALUES
(1, 'Boba Bliss', 1),
(2, 'Joe''s Café', 2),
(3, 'Fran and Frank', 3),
(4, 'Ben''s Leaning Tower of Pizza', NULL);
