-- Create the activities table if it doesn't already exist
CREATE TABLE IF NOT EXISTS activities (
    activity_id INTEGER PRIMARY KEY,
    activity_name TEXT,
    equipment_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM activities;

-- Insert data into the activities table
INSERT INTO activities (activity_id, activity_name, equipment_id) VALUES
(1, 'Running', 1),
(2, 'Weightlifting', 2),
(3, 'Cycling', 3),
(4, 'Swimming', 4),
(5, 'Yoga', 5),
(6, 'Dance', 6),
(7, 'Pilates', 7),
(8, 'Obstacle course racing', 8);

-- Create the attendances table if it doesn't already exist
CREATE TABLE IF NOT EXISTS attendances (
    attendance_id INTEGER PRIMARY KEY,
    member_id INTEGER,
    attendance_date TEXT,
    class_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM attendances;

-- Insert data into the attendances table
INSERT INTO attendances (attendance_id, member_id, attendance_date, class_id) VALUES
(1, 1, '2024-01-15', 1),
(2, 2, '2024-01-15', 2),
(3, 3, '2024-01-15', 3),
(4, 4, '2024-01-16', 1),
(5, 5, '2024-01-16', 2),
(6, 6, '2024-01-16', 3),
(7, 7, '2024-01-17', 4),
(8, 8, '2024-01-17', 5),
(9, 9, '2024-01-17', 6),
(10, 10, '2024-01-18', 1);

-- Create the classes table if it doesn't already exist
CREATE TABLE IF NOT EXISTS classes (
    class_id INTEGER PRIMARY KEY,
    class_name TEXT,
    trainer_id INTEGER,
    capacity INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM classes;

-- Insert data into the classes table
INSERT INTO classes (class_id, class_name, trainer_id, capacity) VALUES
(1, 'Yoga', 1, 15),
(2, 'Cardio Blast', 2, 20),
(3, 'Strength Training', 3, 12),
(4, 'Zumba', 1, 25),
(5, 'Spin', 2, 18),
(6, 'Pilates', 3, 10);

-- Create the equipment table if it doesn't already exist
CREATE TABLE IF NOT EXISTS equipment (
    equipment_id INTEGER PRIMARY KEY,
    equipment_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM equipment;

-- Insert data into the equipment table
INSERT INTO equipment (equipment_id, equipment_name) VALUES
(1, 'Treadmill'),
(2, 'Barbells'),
(3, 'Stationary Bike'),
(4, 'Swimming Pool'),
(5, 'Yoga Mat'),
(6, 'Stereo'),
(7, 'Pilates Reformer'),
(8, 'Tires');

-- Create the trainers table if it doesn't already exist
CREATE TABLE IF NOT EXISTS trainers (
    trainer_id INTEGER PRIMARY KEY,
    trainer_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM trainers;

-- Insert data into the trainers table
INSERT INTO trainers (trainer_id, trainer_name) VALUES
(1, 'Brock'),
(2, 'Misty'),
(3, 'Gary'),
(4, 'Ash');

-- Create the members table if it doesn't already exist
CREATE TABLE IF NOT EXISTS members (
    member_id INTEGER PRIMARY KEY,
    first_name TEXT,
    last_name TEXT,
    membership_id INTEGER,
    trainer_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM members;

-- Insert data into the members table
INSERT INTO members (member_id, first_name, last_name, membership_id, trainer_id) VALUES
(1, 'Aruna', 'Patel', 1, 1),
(2, 'Jin-Ho', 'Kim', 2, 2),
(3, 'Jasper', 'Singh', 3, 3),
(4, 'Santiago', 'Lopez', 4, 1),
(5, 'Jason', 'Chen', 5, 2),
(6, 'Aisha', 'Abdullah', 6, 3),
(7, 'Alessia', 'Ricci', 7, 1),
(8, 'Ravi', 'Gupta', 8, 2),
(9, 'Ashwini', 'Naidu', 9, 2),
(10, 'Amira', 'Tan', 10, 3);

-- Create the memberships table if it doesn't already exist
CREATE TABLE IF NOT EXISTS memberships (
    membership_id INTEGER PRIMARY KEY,
    membership_type TEXT,
    monthly_fee REAL
);

-- Clear any existing data to ensure idempotency
DELETE FROM memberships;

-- Insert data into the memberships table
INSERT INTO memberships (membership_id, membership_type, monthly_fee) VALUES
(1, 'Basic', 50),
(2, 'Standard', 75),
(3, 'Premium', 100);

-- Create the payments table if it doesn't already exist
CREATE TABLE IF NOT EXISTS payments (
    payment_id INTEGER PRIMARY KEY,
    member_id INTEGER,
    payment_date TEXT,
    payment_amount REAL
);

-- Clear any existing data to ensure idempotency
DELETE FROM payments;

-- Insert data into the payments table
INSERT INTO payments (payment_id, member_id, payment_date, payment_amount) VALUES
(2, 1, '2024-01-01', 50),
(3, 2, '2024-01-01', 75),
(4, 3, '2024-01-01', 100),
(5, 4, '2024-01-01', 50),
(6, 5, '2024-01-01', 75),
(7, 6, '2024-01-01', 100),
(8, 7, '2024-01-01', 50),
(9, 8, '2024-01-01', 75),
(10, 9, '2024-01-01', 75),
(11, 10, '2024-01-01', 100);

-- Create the sessions table if it doesn't already exist
CREATE TABLE IF NOT EXISTS sessions (
    session_id INTEGER PRIMARY KEY,
    class_id INTEGER,
    session_date TEXT,
    session_time TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM sessions;

-- Insert data into the sessions table
INSERT INTO sessions (session_id, class_id, session_date, session_time) VALUES
(1, 1, '2024-01-15', '10:00:00'),
(2, 2, '2024-01-15', '11:00:00'),
(3, 3, '2024-01-15', '12:00:00'),
(4, 1, '2024-01-16', '10:00:00'),
(5, 2, '2024-01-16', '11:00:00'),
(6, 3, '2024-01-16', '12:00:00'),
(7, 4, '2024-01-17', '10:00:00'),
(8, 5, '2024-01-17', '11:00:00'),
(9, 6, '2024-01-17', '12:00:00'),
(10, 1, '2024-01-18', '10:00:00'),
(11, 2, '2024-01-18', '11:00:00'),
(12, 3, '2024-01-18', '12:00:00');
