-- Create the attractions table
CREATE TABLE IF NOT EXISTS attractions (
    activity_id INTEGER PRIMARY KEY AUTOINCREMENT,
    activity_name TEXT NOT NULL,
    city TEXT NOT NULL,
    price REAL CHECK (price > 0)
);

-- Clear any existing data to ensure idempotency
DELETE FROM attractions;

-- Insert data into the attractions table
INSERT INTO attractions (activity_name, city, price) VALUES
('Boat Tour', 'Miami', 50.00),
('South Beach Nightlife Tour', 'Miami', 50.00),
('Art Walk', 'Miami', 20.00),
('Kayaking', 'Miami', 35.00),
('City Tour', 'Miami', 30.00),
('Beach Bus', 'Miami', 15.00),
('Museum Visit', 'Miami', 15.00);

-- Create the beaches table
CREATE TABLE IF NOT EXISTS beaches (
    beach_name TEXT PRIMARY KEY
);

-- Clear any existing data to ensure idempotency
DELETE FROM beaches;

-- Insert data into the beaches table
INSERT INTO beaches (beach_name) VALUES
('Clearwater Beach'),
('Siesta Beach'),
('South Beach'),
('Pensacola Beach'),
('Daytona Beach');

-- Create the hotels table
CREATE TABLE IF NOT EXISTS hotels (
    hotel_id INTEGER PRIMARY KEY AUTOINCREMENT,
    hotel_name TEXT NOT NULL,
    city TEXT NOT NULL,
    stars INTEGER CHECK (stars BETWEEN 1 AND 5),
    price_per_night REAL CHECK (price_per_night > 0)
);

-- Clear any existing data to ensure idempotency
DELETE FROM hotels;

-- Insert data into the hotels table
INSERT INTO hotels (hotel_name, city, stars, price_per_night) VALUES
('Key Tampa Resort', 'Tampa', 5, 350.00),
('Bald Cypress Hotel', 'Tampa', 4, 220.00),
('Stone Crab Inn', 'Tampa', 4, 200.00),
('Bolt Resort', 'Tampa', 3, 150.00);

-- Create the islands table
CREATE TABLE IF NOT EXISTS islands (
    island_name TEXT PRIMARY KEY,
    distance INTEGER CHECK (distance > 0)
);

-- Clear any existing data to ensure idempotency
DELETE FROM islands;

-- Insert data into the islands table
INSERT INTO islands (island_name, distance) VALUES
('Key West', 165),
('Sanibel Island', 170),
('Amelia Island', 350),
('Marco Island', 105),
('Anna Maria Island', 180);

-- Create the museums table
CREATE TABLE IF NOT EXISTS museums (
    museum_name TEXT PRIMARY KEY,
    city TEXT NOT NULL
);

-- Clear any existing data to ensure idempotency
DELETE FROM museums;

-- Insert data into the museums table
INSERT INTO museums (museum_name, city) VALUES
('Salvador Dalí Museum', 'St. Petersburg'),
('John and Mable Ringling Museum of Art', 'Sarasota'),
('Museum of Discovery and Science', 'Fort Lauderdale'),
('Frost Science Museum', 'Miami'),
('Kennedy Space Center Visitor Complex', 'Merritt Island'),
('Henry B. Plant Museum', 'Tampa'),
('Norton Museum of Art', 'West Palm Beach'),
('Morikami Museum and Japanese Gardens', 'Delray Beach'),
('Lightner Museum', 'St. Augustine'),
('Museum of Fine Arts', 'St. Petersburg');

-- Create the restaurants table
CREATE TABLE IF NOT EXISTS restaurants (
    restaurant_id INTEGER PRIMARY KEY AUTOINCREMENT,
    restaurant_name TEXT NOT NULL,
    city TEXT NOT NULL,
    rating REAL CHECK (rating BETWEEN 0 AND 5)
);

-- Clear any existing data to ensure idempotency
DELETE FROM restaurants;

-- Insert data into the restaurants table
INSERT INTO restaurants (restaurant_name, city, rating) VALUES
('Valencia & Hamlin Bistro', 'Orlando', 4.5),
('Florida Man''s Table', 'Orlando', 5.0),
('Everglades Mangrove', 'Orlando', 4.7),
('Beautiful Sushi', 'Orlando', 4.8),
('On Sunshine Cafe', 'Orlando', 4.3);

-- Create the souvenirs table
CREATE TABLE IF NOT EXISTS souvenirs (
    city TEXT,
    item TEXT,
    price REAL CHECK (price >= 0)
);

-- Clear any existing data to ensure idempotency
DELETE FROM souvenirs;

-- Insert data into the souvenirs table
INSERT INTO souvenirs (city, item, price) VALUES
('Tampa', 'Keychain', 5.00),
('Tampa', 'Keychain', 7.95),
('Tampa', 'T-shirt', 20.00),
('Tampa', 'Mug', 10.00),
('Tampa', 'Mug', 12.90),
('Tampa', 'Hat', 15.00),
('Tampa', 'Postcard', 1.00);

-- Create the state_parks table
CREATE TABLE IF NOT EXISTS state_parks (
    park_name TEXT PRIMARY KEY,
    hiking_trails TEXT CHECK (hiking_trails IN ('Yes', 'No'))
);

-- Clear any existing data to ensure idempotency
DELETE FROM state_parks;

-- Insert data into the state_parks table
INSERT INTO state_parks (park_name, hiking_trails) VALUES
('Everglades National Park', 'Yes'),
('Biscayne National Park', 'Yes'),
('Ocala National Forest', 'No'),
('Big Cypress National Preserve', 'Yes'),
('Myakka River State Park', 'Yes');

