-- Create the alarms table if it doesn't already exist
CREATE TABLE IF NOT EXISTS alarms (
    alarm_id INTEGER PRIMARY KEY,
    alarm_type TEXT,
    sensor_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM alarms;

-- Insert data into the alarms table
INSERT INTO alarms (alarm_id, alarm_type, sensor_id) VALUES
(1, 'Motion', 2),
(2, 'Door', 1),
(3, 'Smoke', 4),
(4, 'Window', 7),
(5, 'Motion', 5);

-- Create the devices table if it doesn't already exist
CREATE TABLE IF NOT EXISTS devices (
    device_id INTEGER PRIMARY KEY,
    device_name TEXT,
    room_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM devices;

-- Insert data into the devices table
INSERT INTO devices (device_id, device_name, room_id) VALUES
(1, 'Smart Lock', 1),
(2, 'Motion Sensor', 2),
(3, 'Security Camera', 1),
(4, 'Smart Bulb', 3),
(5, 'Smart Thermostat', 2),
(6, 'Smart Speaker', 2),
(7, 'Window Sensor', 3),
(8, 'Smoke Detector', 4),
(9, 'Smart Fan', 3),
(10, 'Smart Plug', 2);

-- Create the events table if it doesn't already exist
CREATE TABLE IF NOT EXISTS events (
    event_id INTEGER PRIMARY KEY,
    event_time TEXT,
    sensor_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM events;

-- Insert data into the events table
INSERT INTO events (event_id, event_time, sensor_id) VALUES
(1, '08:00', 1),
(2, '12:30', 2),
(3, '17:45', 3),
(4, '20:15', 2),
(5, '09:15', 7),
(6, '11:00', 1),
(7, '18:30', 2),
(8, '10:00', 4),
(9, '14:45', 2),
(10, '21:20', 1);

-- Create the rooms table if it doesn't already exist
CREATE TABLE IF NOT EXISTS rooms (
    room_id INTEGER PRIMARY KEY,
    room_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM rooms;

-- Insert data into the rooms table
INSERT INTO rooms (room_id, room_name) VALUES
(1, 'Front Door'),
(2, 'Living Room'),
(3, 'Bedroom'),
(4, 'Kitchen'),
(5, 'Bathroom');

-- Create the sensors table if it doesn't already exist
CREATE TABLE IF NOT EXISTS sensors (
    sensor_id INTEGER PRIMARY KEY,
    sensor_name TEXT,
    room_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM sensors;

-- Insert data into the sensors table
INSERT INTO sensors (sensor_id, sensor_name, room_id) VALUES
(1, 'Front Door Sensor', 1),
(2, 'Living Room Motion Sensor', 2),
(3, 'Security Camera - Front Door', 1),
(4, 'Kitchen Smoke Detector', 4),
(5, 'Bathroom Motion Sensor', 5),
(6, 'Smart Thermostat Sensor', 2),
(7, 'Bedroom Window Sensor', 3),
(8, 'Garage Door Sensor', NULL),
(9, 'Garden Motion Sensor', NULL);
