-- Create the cameras table if it doesn't already exist
CREATE TABLE IF NOT EXISTS cameras (
    camera_id INTEGER PRIMARY KEY,
    brand TEXT,
    model TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM cameras;

-- Insert data into the cameras table
INSERT INTO cameras (camera_id, brand, model) VALUES
(1, 'Canon', 'EOS R5'),
(2, 'Sony', 'A7 III'),
(3, 'Nikon', 'D850');

-- Create the clients table if it doesn't already exist
CREATE TABLE IF NOT EXISTS clients (
    id INTEGER PRIMARY KEY,
    email TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM clients;

-- Insert data into the clients table
INSERT INTO clients (id, email) VALUES
(1, 'sarahj92@upskew.com'),
(2, 'jona@upskew.com'),
(3, 'hiliary@upskew.com');

-- Create the lenses table if it doesn't already exist
CREATE TABLE IF NOT EXISTS lenses (
    lens_id INTEGER PRIMARY KEY,
    camera_id INTEGER,
    focal_length TEXT,
    aperture TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM lenses;

-- Insert data into the lenses table
INSERT INTO lenses (lens_id, camera_id, focal_length, aperture) VALUES
(201, 1, '50mm', '1.2'),
(202, 2, '24-70mm', '2.8'),
(203, 1, '24-105mm', '4.0'),
(204, 3, '70-200mm', '2.8');

-- Create the participants table if it doesn't already exist
CREATE TABLE IF NOT EXISTS participants (
    participant INTEGER PRIMARY KEY,
    workshop INTEGER,
    participant_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM participants;

-- Insert data into the participants table
INSERT INTO participants (participant, workshop, participant_name) VALUES
(501, 301, 'Charles'),
(502, 301, 'Gabriel'),
(503, 302, 'Lana');

-- Create the photoshoots table if it doesn't already exist
CREATE TABLE IF NOT EXISTS photoshoots (
    client_id INTEGER,
    location TEXT,
    bill INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM photoshoots;

-- Insert data into the photoshoots table
INSERT INTO photoshoots (client_id, location, bill) VALUES
(1, 'Central Park', 200),
(2, 'Brooklyn Bridge', 400),
(3, 'Times Square', 300);

-- Create the workshops table if it doesn't already exist
CREATE TABLE IF NOT EXISTS workshops (
    id INTEGER PRIMARY KEY,
    workshop_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM workshops;

-- Insert data into the workshops table
INSERT INTO workshops (id, workshop_name) VALUES
(301, 'Landscape Photography'),
(302, 'Portrait Photography');

-- Create the photos table if it doesn't already exist
CREATE TABLE IF NOT EXISTS photos (
    id INTEGER PRIMARY KEY,
    photo_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM photos;

-- Insert data into the photos table
INSERT INTO photos (id, photo_name) VALUES
(101, 'Sunset'),
(102, 'Mountain');

-- Create the albums table if it doesn't already exist
CREATE TABLE IF NOT EXISTS albums (
    photo_id INTEGER,
    album_name TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM albums;

-- Insert data into the albums table
INSERT INTO albums (photo_id, album_name) VALUES
(101, 'Nature'),
(102, 'Adventure');
