-- Create the driver_locations table if it doesn't already exist
CREATE TABLE IF NOT EXISTS driver_locations (
    location_id INTEGER PRIMARY KEY,
    driver_id INTEGER,
    city TEXT
);

-- Create the drivers table if it doesn't already exist
CREATE TABLE IF NOT EXISTS drivers (
    driver_id INTEGER PRIMARY KEY,
    user_id INTEGER,
    name TEXT,
    vehicle_type_id INTEGER
);

-- Create the payment_methods table if it doesn't already exist
CREATE TABLE IF NOT EXISTS payment_methods (
    method_id INTEGER PRIMARY KEY,
    method_name TEXT
);

-- Create the promotions table if it doesn't already exist
CREATE TABLE IF NOT EXISTS promotions (
    promo_id INTEGER PRIMARY KEY,
    promo_code TEXT
);

-- Create the rides table if it doesn't already exist
CREATE TABLE IF NOT EXISTS rides (
    ride_id INTEGER PRIMARY KEY,
    driver_id INTEGER,
    promo_id INTEGER
);

-- Create the user_ratings table if it doesn't already exist
CREATE TABLE IF NOT EXISTS user_ratings (
    rating_id INTEGER PRIMARY KEY,
    ride_id INTEGER,
    stars INTEGER
);

-- Create the users table if it doesn't already exist
CREATE TABLE IF NOT EXISTS users (
    user_id INTEGER PRIMARY KEY,
    name TEXT,
    default_payment_id INTEGER
);

-- Create the vehicle_types table if it doesn't already exist
CREATE TABLE IF NOT EXISTS vehicle_types (
    vehicle_type_id INTEGER PRIMARY KEY,
    description TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM driver_locations;

-- Insert data into the driver_locations table
INSERT INTO driver_locations (location_id, driver_id, city) VALUES
(1, 1, 'New York'),
(2, 2, 'Los Angeles'),
(3, 3, 'Chicago'),
(4, 4, 'Houston'),
(5, 5, 'Philadelphia'),
(6, 6, 'Phoenix');

-- Clear any existing data to ensure idempotency
DELETE FROM drivers;

-- Insert data into the drivers table
INSERT INTO drivers (driver_id, name, vehicle_type_id, user_id) VALUES
(1, 'Lyla Humphrey', 1, 8),
(2, 'Alannah Bishop', 2, 9),
(3, 'Shea Owens', 2, 10),
(4, 'Aaliyah Mcdonald', 3, NULL),
(5, 'Elias Evans', 1, NULL),
(6, 'Harper Mitchell', 3, NULL),
(7, 'Theodore Davis', 2, NULL);

-- Clear any existing data to ensure idempotency
DELETE FROM payment_methods;

-- Insert data into the payment_methods table
INSERT INTO payment_methods (method_id, method_name) VALUES
(1, 'Credit Card'),
(2, 'PayPal'),
(3, 'Bank Transfer'),
(4, 'Venmo'),
(5, 'Apple Pay'),
(6, 'Google Pay');

-- Clear any existing data to ensure idempotency
DELETE FROM promotions;

-- Insert data into the promotions table
INSERT INTO promotions (promo_id, promo_code) VALUES
(1, 'SUMMER20'),
(2, 'RIDE5OFF'),
(3, 'FIRSTTRIP'),
(4, 'WEEKEND10'),
(5, 'HOLIDAY25');

-- Clear any existing data to ensure idempotency
DELETE FROM rides;

-- Insert data into the rides table
INSERT INTO rides (ride_id, driver_id, promo_id) VALUES
(1, 3, 1),
(2, 2, 2),
(3, 1, NULL),
(4, 6, 3),
(5, 4, NULL),
(6, 7, 4),
(7, 5, 1);

-- Clear any existing data to ensure idempotency
DELETE FROM user_ratings;

-- Insert data into the user_ratings table
INSERT INTO user_ratings (rating_id, ride_id, stars) VALUES
(1, 1, 4),
(2, 2, 5),
(3, 3, 3),
(4, 5, 5),
(5, 6, 2),
(6, 7, 4);

-- Clear any existing data to ensure idempotency
DELETE FROM users;

-- Insert data into the users table
INSERT INTO users (user_id, name, default_payment_id) VALUES
(1, 'Liam', 1),
(2, 'Mason', 2),
(3, 'Isabella', 3),
(4, 'Zoe', NULL),
(5, 'Olivia', NULL),
(6, 'Sophia', 4),
(7, 'Jackson', 5),
(8, 'Lyla', 5),
(9, 'Alannah', 5),
(10, 'Shea', 5);

-- Clear any existing data to ensure idempotency
DELETE FROM vehicle_types;

-- Insert data into the vehicle_types table
INSERT INTO vehicle_types (vehicle_type_id, description) VALUES
(1, 'Compact'),
(2, 'SUV'),
(3, 'Luxury Sedan'),
(4, 'Minivan'),
(5, 'Electric Car'),
(6, 'Pickup Truck');