-- Create the users table if it doesn't already exist
CREATE TABLE IF NOT EXISTS users (
    user_id INTEGER PRIMARY KEY,
    username TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM users;

-- Insert data into the users table
INSERT INTO users (user_id, username) VALUES
(1, 'sparkling_unicorn'),
(2, 'coding_ninja'),
(3, 'bookworm42'),
(4, 'foodie_adventures'),
(5, 'music_lover123');

-- Create the posts table if it doesn't already exist
CREATE TABLE IF NOT EXISTS posts (
    post_id INTEGER PRIMARY KEY,
    user_id INTEGER,
    caption TEXT
);

-- Clear any existing data to ensure idempotency
DELETE FROM posts;

-- Insert data into the posts table
INSERT INTO posts (post_id, user_id, caption) VALUES
(1, 1, 'Just saw the most beautiful sunset! #grateful'),
(2, 3, 'Finished reading a great book! Any recommendations?'),
(3, 2, 'New blog post up! Learn how to code your first website.'),
(4, 5, 'Can''t stop listening to this new song! #musiclover'),
(5, 4, 'Trying out a new restaurant tonight! #foodie'),
(6, 1, 'Feeling inspired today! ✨');

-- Create the likes table if it doesn't already exist
CREATE TABLE IF NOT EXISTS likes (
    like_id INTEGER PRIMARY KEY,
    post_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM likes;

-- Insert data into the likes table
INSERT INTO likes (like_id, post_id) VALUES
(1, 1),
(2, 1),
(3, 2),
(4, 3),
(5, 4),
(6, 5),
(7, 2),
(8, 4);

-- Create the followers table if it doesn't already exist
CREATE TABLE IF NOT EXISTS followers (
    follower_id INTEGER,
    user_id INTEGER
);

-- Clear any existing data to ensure idempotency
DELETE FROM followers;

-- Insert data into the followers table
INSERT INTO followers (follower_id, user_id) VALUES
(2, 1),
(3, 1),
(4, 1),
(5, 2),
(2, 3),
(3, 4);