-- Create the customers table
CREATE TABLE IF NOT EXISTS customers (
    customer_id INTEGER PRIMARY KEY,
    first_name TEXT NOT NULL,
    last_name TEXT NOT NULL,
    email TEXT NOT NULL UNIQUE
);

-- Clear any existing data to ensure idempotency
DELETE FROM customers;

-- Insert data into the customers table
INSERT INTO customers (customer_id, first_name, last_name, email) VALUES
(1, 'Eden', 'Maizland', 'eden@upskew.com'),
(2, 'Diego', 'Shea', 'Diego_Shea42@upskew.com'),
(3, 'Karl', 'Garcia', 'Karl_Garcia2@upskew.com'),
(4, 'Will', 'Nguyen', 'Will_Nguyen50@upskew.com'),
(5, 'Mary', 'Cronin', 'Mary_Cronin61@upskew.com'),
(6, 'Doug', 'Silva', 'Doug_Silva94@upskew.com'),
(7, 'Jay', 'User', 'jay_user@upskew.com'),
(999, 'Test', 'User', 'test_user@upskew.com');

-- Create the equipment table
CREATE TABLE IF NOT EXISTS equipment (
    equipment_id INTEGER PRIMARY KEY,
    item TEXT NOT NULL,
    size TEXT,
    condition TEXT,
    rental_rate REAL NOT NULL CHECK (rental_rate > 0)
);

-- Clear any existing data to ensure idempotency
DELETE FROM equipment;

-- Insert data into the equipment table
INSERT INTO equipment (equipment_id, item, size, condition, rental_rate) VALUES
(1, 'basketball', '7', 'good', 10.00),
(2, 'basketball', '7', 'good', 10.00),
(3, 'basketball', '5', 'good', 8.00),
(4, 'soccer ball', '5', 'good', 8.00),
(5, 'soccer ball', '4', 'good', 8.00),
(6, 'i need coffee', NULL, NULL, 5.00),
(7, 'baseball bat', 'youth', 'good', 7.00),
(8, 'baseball bat', 'adult', 'good', 10.00),
(9, 'tennis racket', 'adult', 'good', 8.00),
(10, 'baseball bat', 'junior', 'damaged', 12.00),
(11, 'tennis racket', 'youth', 'good', 8.00),
(12, 'hockey stick', 'junior', 'damaged', 12.00),
(13, 'hockey stick', 'senior', 'good', 15.00),
(14, 'hockey stick', 'senior', 'damaged', 15.00);

-- Create the rentals table
CREATE TABLE IF NOT EXISTS rentals (
    rental_id INTEGER,
    customer_id INTEGER,
    amount REAL NOT NULL CHECK (amount > 0)
);

-- Clear any existing data to ensure idempotency
DELETE FROM rentals;

-- Insert data into the rentals table
INSERT INTO rentals (rental_id, customer_id, amount) VALUES
(123, 1, 30.00),
(234, 2, 16.00),
(345, 3, 15.00),
(456, 4, 24.00),
(567, 5, 57.00),
(567, 5, 56.00),
(678, 6, 14.00),
(789, 1, 18.00),
(890, 2, 22.00),
(999, 3, 26.00);

-- Create the returns table
CREATE TABLE IF NOT EXISTS returns (
    return_id INTEGER,
    rental_id INTEGER,
    late_fee REAL CHECK (late_fee >= 0)
);

-- Clear any existing data to ensure idempotency
DELETE FROM returns;

-- Insert data into the returns table
INSERT INTO returns (return_id, rental_id, late_fee) VALUES
(987, 456, 2.50),
(876, 345, 0.00),
(765, 234, 2.50),
(654, 123, 5.00);
